:py:mod:`piel.gdsfactory`
=========================

.. py:module:: piel.gdsfactory


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.gdsfactory.create_gdsfactory_component



.. py:function:: create_gdsfactory_component(design_directory: str)

   This function cretes a gdsfactory component that can be included in the network connectivity of the device, or that can be used for interconnection connectivity.


